@@ -259,7 +259,7 @@ void ppack (int fdes, enum ck_msg_type type, CheckMsg *msg)
   n = pack (type, &buf, msg);
   r = write (fdes, buf, n);
   if (r == -1)
-    eprintf ("Error in ppack:",__FILE__,__LINE__);
+    eprintf ("Error in call to write:", __FILE__, __LINE__ - 2);
 
   free (buf);
 }
@@ -279,7 +279,7 @@ static int read_buf (int fdes, char **buf)
     if (n == 0)
       break;
     if (n == -1)
-      eprintf ("Error in read_buf:", __FILE__, __LINE__);
+      eprintf ("Error in call to read:", __FILE__, __LINE__ - 4);
 
     nread += n;
     size *= grow;
@@ -299,14 +299,14 @@ static int get_result (char *buf, RcvMsg *rmsg)
 
   n = upack (buf, &msg, &type);
   if (n == -1)
-    eprintf ("Error in upack", __FILE__, __LINE__);
+    eprintf ("Error in call to upack", __FILE__, __LINE__ - 2);
   
   if (type == CK_MSG_CTX) {
     CtxMsg *cmsg = (CtxMsg *) &msg;
     rcvmsg_update_ctx (rmsg, cmsg->ctx);
   } else if (type == CK_MSG_LOC) {
     LocMsg *lmsg = (LocMsg *) &msg;
-    if (rmsg->failctx == -1)
+    if (rmsg->failctx == CK_CTX_INVALID)
     {
       rcvmsg_update_loc (rmsg, lmsg->file, lmsg->line);
     }
@@ -347,8 +347,8 @@ static RcvMsg *rcvmsg_create (void)
   RcvMsg *rmsg;
 
   rmsg = emalloc (sizeof (RcvMsg));
-  rmsg->lastctx = -1;
-  rmsg->failctx = -1;
+  rmsg->lastctx = CK_CTX_INVALID;
+  rmsg->failctx = CK_CTX_INVALID;
   rmsg->msg = NULL;
   reset_rcv_test (rmsg);
   reset_rcv_fixture (rmsg);
@@ -365,7 +365,7 @@ void rcvmsg_free (RcvMsg *rmsg)
 
 static void rcvmsg_update_ctx (RcvMsg *rmsg, enum ck_result_ctx ctx)
 {
-  if (rmsg->lastctx != -1)
+  if (rmsg->lastctx != CK_CTX_INVALID)
   {
     free(rmsg->fixture_file);
     reset_rcv_fixture (rmsg);
@@ -408,7 +408,7 @@ RcvMsg *punpack (int fdes)
   }
 
   free (obuf);
-  if (rmsg->lastctx == -1) {
+  if (rmsg->lastctx == CK_CTX_INVALID) {
     free (rmsg);
     rmsg = NULL;
   }
